@@ -4,5 +4,5 @@ export { DeviceEnrolmentService } from "./device-enrolment.service";
 export { DeviceEnrolledGuard } from "./device-enrolled.guard";
 export { DeviceGpsLocationService } from "./gps-location.service";
 export { DeviceGpsLocationTuple } from "./DeviceGpsLocationTuple";
-export { DeviceOfflineCacheControllerService } from "./device-offline-cache-controller.service";
+export { DeviceOfflineCacheService } from "./device-offline-cache.service";
 export { OfflineCacheStatusTuple } from "./tuples/OfflineCacheStatusTuple";
